@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -16,7 +16,7 @@ from time import time
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import App, Type, OrderBy, StorageType
 from lollypop.logger import Logger
-from lollypop.utils import noaccents, get_default_storage_type, remove_static
+from lollypop.utils import get_default_storage_type, remove_static
 
 
 class AlbumsDatabase:
@@ -459,7 +459,7 @@ class AlbumsDatabase:
                 return v[0]
             return None
 
-    def get_id_by(self, album_name, artist_ids):
+    def get_id_for_escaped_string(self, album_name, artist_ids):
         """
             Get album for name and artists
             @param album_name as escaped str
@@ -470,11 +470,13 @@ class AlbumsDatabase:
             filters = (album_name,)
             request = "SELECT albums.rowid FROM albums, album_artists\
                        WHERE sql_escape(name)=? COLLATE NOCASE AND\
-                       album_artists.album_id=albums.rowid AND (1=0 "
-            filters += tuple(artist_ids)
-            for artist_id in artist_ids:
-                request += "OR artist_id=? "
-            request += ")"
+                       album_artists.album_id=albums.rowid"
+            if artist_ids:
+                request += " AND (1=0 "
+                filters += tuple(artist_ids)
+                for artist_id in artist_ids:
+                    request += "OR artist_id=? "
+                request += ")"
             result = sql.execute(request, filters)
             v = result.fetchone()
             if v is not None:
@@ -558,6 +560,20 @@ class AlbumsDatabase:
             result = sql.execute("SELECT mb_album_id FROM albums\
                                   WHERE rowid=?", (album_id,))
             v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return ""
+
+    def get_id_for_mb_album_id(self, mb_album_id):
+        """
+            Get album id for MusicBrainz recording id
+            @param MusicBrainz id as str
+            @return album id as int
+        """
+        with SqlCursor(App().db) as sql:
+            result = sql.execute("SELECT rowid FROM albums\
+                                  WHERE mb_album_id=?", (mb_album_id,))
+            v = result.fetchone()
             if v is not None:
                 return v[0]
             return -1
@@ -1084,7 +1100,11 @@ class AlbumsDatabase:
             @return ([int], bool)
         """
         with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT albums.year FROM albums")
+            storage_type = get_default_storage_type()
+            result = sql.execute("SELECT albums.year\
+                                  FROM albums\
+                                  WHERE storage_type & ?",
+                                 (storage_type,))
             years = []
             unknown = False
             for year in list(itertools.chain(*result)):
@@ -1177,34 +1197,17 @@ class AlbumsDatabase:
     def search(self, searched, storage_type):
         """
             Search for albums looking like string
-            @param searched as str
+            @param searched as str without accents
             @param storage_type as StorageType
             @return album ids as [int]
         """
         with SqlCursor(App().db) as sql:
-            no_accents = noaccents(searched)
-            items = []
-            # From best filter to worst filter
-            for filter in [(no_accents + "%", storage_type),
-                           ("%" + no_accents, storage_type),
-                           ("%" + no_accents + "%", storage_type)]:
-                request = "SELECT albums.rowid FROM albums\
-                           WHERE noaccents(name) LIKE ?\
-                           AND albums.storage_type & ? LIMIT 25"
-                result = sql.execute(request, filter)
-                items += list(itertools.chain(*result))
-            for filter in [(no_accents + "%", storage_type),
-                           ("%" + no_accents, storage_type),
-                           ("%" + no_accents + "%", storage_type)]:
-                request = "SELECT DISTINCT albums.rowid\
-                       FROM albums, album_artists, artists\
-                       WHERE album_artists.artist_id=artists.rowid AND\
-                       album_artists.album_id=albums.rowid AND\
-                       noaccents(artists.name) LIKE ? AND\
-                       albums.storage_type & ? LIMIT 25"
-                result = sql.execute(request, filter)
-                items += list(itertools.chain(*result))
-            return list(set(items))
+            filters = ("%" + searched + "%", storage_type)
+            request = "SELECT rowid, name FROM albums\
+                       WHERE noaccents(name) LIKE ?\
+                       AND albums.storage_type & ? LIMIT 25"
+            result = sql.execute(request, filters)
+            return list(result)
 
     def calculate_artist_ids(self, album_id):
         """
