@@ -216,6 +216,14 @@ class LastFMBase:
             else:
                 self.unlove(",".join(track.artists), track.name)
 
+    @property
+    def login(self):
+        """
+            Get current login
+            @return str
+        """
+        return self.__login
+
     @property
     def is_goa(self):
         """
@@ -240,6 +248,24 @@ class LastFMBase:
         """
         return self.__name
 
+#######################
+# PROTECTED           #
+#######################
+    def _connect(self, full_sync=False):
+        """
+            Connect service
+            @param full_sync as bool
+            @thread safe
+        """
+        try:
+            self.session_key = ""
+            skg = SessionKeyGenerator(self)
+            self.session_key = skg.get_session_key(
+                username=self.__login,
+                password_hash=md5(self.__password))
+        except Exception as e:
+            Logger.error("LastFMBase::_connect(): %s" % e)
+
 #######################
 # PRIVATE             #
 #######################
@@ -257,21 +283,6 @@ class LastFMBase:
         if self.__queue_id is None:
             self.__queue_id = GLib.timeout_add(1000, queue)
 
-    def _connect(self, full_sync=False):
-        """
-            Connect service
-            @param full_sync as bool
-            @thread safe
-        """
-        try:
-            self.session_key = ""
-            skg = SessionKeyGenerator(self)
-            self.session_key = skg.get_session_key(
-                username=self.__login,
-                password_hash=md5(self.__password))
-        except Exception as e:
-            Logger.debug("LastFM::_connect(): %s" % e)
-
     def __listen(self, artist, album, title, timestamp, mb_track_id):
         """
             Scrobble track
@@ -322,27 +333,6 @@ class LastFMBase:
         except Exception as e:
             Logger.error("LastFM::__playing_now(): %s" % e)
 
-    def __populate_loved_tracks(self):
-        """
-            Populate loved tracks playlist
-        """
-        if not self.available:
-            return
-        try:
-            user = self.get_user(self.__login)
-            for loved in user.get_loved_tracks(limit=None):
-                artist = str(loved.track.artist)
-                title = str(loved.track.title)
-                track_id = App().tracks.search_track(artist, title)
-                if track_id is None:
-                    Logger.warning(
-                        "LastFM::__populate_loved_tracks(): %s, %s" % (
-                            artist, title))
-                else:
-                    Track(track_id).set_loved(1)
-        except Exception as e:
-            Logger.error("LastFM::__populate_loved_tracks: %s" % e)
-
     def __on_get_password(self, attributes, password,
                           name, full_sync, callback, *args):
         """
@@ -382,6 +372,8 @@ class LibreFM(LastFMBase, LibreFMNetwork):
             Init LibreFM
         """
         LibreFMNetwork.__init__(self)
+        if App().proxy_host is not None:
+            self.enable_proxy(host=App().proxy_host, port=App().proxy_port)
         LastFMBase.__init__(self, "librefm")
         Logger.debug("LibreFMNetwork.__init__()")
 
@@ -394,7 +386,7 @@ class LibreFM(LastFMBase, LibreFMNetwork):
         return self.session_key != ""
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _connect(self, full_sync=False):
         """
@@ -408,12 +400,12 @@ class LibreFM(LastFMBase, LibreFMNetwork):
             LastFMBase._connect(self, full_sync)
             self.playing_now(App().player.current_track)
         except Exception as e:
-            Logger.debug("LastFM::_connect(): %s" % e)
+            Logger.error("LastFM::_connect(): %s" % e)
 
 
 class LastFM(LastFMBase, LastFMNetwork):
     """
-        LastFM
+       LastFM
        We recommend you don"t distribute the API key and secret with your app,
        and that you ask users who want to build it to apply for a key of
        their own. We don"t believe that this would violate the terms of most
@@ -441,6 +433,8 @@ class LastFM(LastFMBase, LastFMNetwork):
         LastFMNetwork.__init__(self,
                                api_key=self.__API_KEY,
                                api_secret=self.__API_SECRET)
+        if App().proxy_host is not None:
+            self.enable_proxy(host=App().proxy_host, port=App().proxy_port)
         LastFMBase.__init__(self, "lastfm")
 
     def connect_service(self, full_sync=False, callback=None, *args):
@@ -486,7 +480,7 @@ class LastFM(LastFMBase, LastFMNetwork):
         return True
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _connect(self, full_sync=False):
         """
@@ -511,6 +505,30 @@ class LastFM(LastFMBase, LastFMNetwork):
         except Exception as e:
             Logger.debug("LastFM::_connect(): %s" % e)
 
+#######################
+# PRIVATE             #
+#######################
+    def __populate_loved_tracks(self):
+        """
+            Populate loved tracks playlist
+        """
+        if not self.available:
+            return
+        try:
+            user = self.get_user(self.login)
+            for loved in user.get_loved_tracks(limit=None):
+                artist = str(loved.track.artist)
+                title = str(loved.track.title)
+                track_id = App().tracks.search_track(artist, title)
+                if track_id is None:
+                    Logger.warning(
+                        "LastFM::__populate_loved_tracks(): %s, %s" % (
+                            artist, title))
+                else:
+                    Track(track_id).set_loved(1)
+        except Exception as e:
+            Logger.error("LastFM::__populate_loved_tracks: %s" % e)
+
     def __on_goa_account_switched(self, obj):
         """
             Callback for GoaSyncedAccount signal "account-switched"
