@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -15,12 +15,14 @@ from gi.repository import Gst, GLib, GObject
 from pickle import load
 
 from lollypop.player_albums import AlbumsPlayer
+from lollypop.player_auto_random import AutoRandomPlayer
+from lollypop.player_auto_similar import AutoSimilarPlayer
 from lollypop.player_bin import BinPlayer
 from lollypop.player_queue import QueuePlayer
 from lollypop.player_linear import LinearPlayer
 from lollypop.player_shuffle import ShufflePlayer
 from lollypop.player_radio import RadioPlayer
-from lollypop.player_similars import SimilarsPlayer
+from lollypop.player_transitions import TransitionsPlayer
 from lollypop.radios import Radios
 from lollypop.logger import Logger
 from lollypop.objects_track import Track
@@ -29,8 +31,9 @@ from lollypop.define import App, Type, LOLLYPOP_DATA_PATH
 from lollypop.utils import emit_signal
 
 
-class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
-             RadioPlayer, LinearPlayer, ShufflePlayer, SimilarsPlayer):
+class Player(GObject.GObject, AlbumsPlayer, BinPlayer, AutoRandomPlayer,
+             AutoSimilarPlayer, QueuePlayer, RadioPlayer, LinearPlayer,
+             ShufflePlayer, TransitionsPlayer):
     """
         Player object used to manage playback and playlists
     """
@@ -56,16 +59,29 @@ class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
         """
         GObject.GObject.__init__(self)
         AlbumsPlayer.__init__(self)
+        AutoRandomPlayer.__init__(self)
+        AutoSimilarPlayer.__init__(self)
         BinPlayer.__init__(self)
         QueuePlayer.__init__(self)
         LinearPlayer.__init__(self)
         ShufflePlayer.__init__(self)
         RadioPlayer.__init__(self)
-        SimilarsPlayer.__init__(self)
+        TransitionsPlayer.__init__(self)
         self.__stop_after_track_id = None
-        self.update_crossfading()
         App().settings.connect("changed::repeat", self.update_next_prev)
 
+    def load(self, track):
+        """
+            Stop current track, load track id and play it
+            @param track as Track
+        """
+        if isinstance(track, Radio):
+            RadioPlayer.load(self, track)
+        elif TransitionsPlayer.load(self, track):
+            pass
+        else:
+            BinPlayer.load(self, track)
+
     def prev(self):
         """
             Play previous track
@@ -90,21 +106,6 @@ class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
         else:
             self.stop()
 
-    def load(self, track, play=True):
-        """
-            Stop current track, load track id and play it
-            @param track as Track
-            @param play as bool, ignored for radios
-        """
-        if isinstance(track, Radio):
-            RadioPlayer.load(self, track, play)
-        else:
-            if play:
-                BinPlayer.load(self, track)
-            else:
-                BinPlayer._load_track(self, track)
-                emit_signal(self, "current-changed")
-
     def stop_after(self, track_id):
         """
             Tell player to stop after track_id
@@ -145,7 +146,7 @@ class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
                     name = radios.get_name(self._current_playback_track.id)
                     uri = radios.get_uri(self._current_playback_track.id)
                     track.set_radio(name, uri)
-                    self.load(track, is_playing)
+                    self.load(track)
                 elif self._current_playback_track.uri:
                     if albums:
                         if was_party:
@@ -169,7 +170,7 @@ class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
                         self.pause()
                     position = load(open(LOLLYPOP_DATA_PATH + "/position.bin",
                                     "rb"))
-                    self.seek(position / Gst.SECOND)
+                    self.seek(position)
                 else:
                     Logger.info("Player::restore_state(): track missing")
         except Exception as e:
@@ -233,15 +234,6 @@ class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
                 self.set_next()
             self.set_prev()
 
-    def update_crossfading(self):
-        """
-            Calculate if crossfading is needed
-        """
-        mix = App().settings.get_value("smooth-transitions")
-        party_mix = App().settings.get_value("party-mix")
-        self._crossfading = (mix and not party_mix) or\
-                            (mix and party_mix and self.is_party)
-
     @property
     def next_track(self):
         """
@@ -271,7 +263,7 @@ class Player(GObject.GObject, AlbumsPlayer, BinPlayer, QueuePlayer,
         """
             On stream start, set next and previous track
         """
-        if self.track_in_queue(self._current_track):
+        if self.is_in_queue(self._current_track.id):
             self.remove_from_queue(self._current_track.id)
         else:
             self._current_playback_track = self._current_track
