@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -341,26 +341,21 @@ class TagReader:
             @return year and timestamp (int, int)
         """
         try:
-            (exists, date) = tags.get_date_index("date", 0)
-            dt = year = timestamp = None
-            if exists:
-                year = date.get_year()
-                d = Gst.DateTime.new_local_time(year, 1, 1, 0, 0, 0)
-                dt = d.to_g_date_time()
-                timestamp = dt.to_unix()
-            else:
-                (exists, date) = tags.get_date_time_index("datetime", 0)
+            date_index = tags.get_date_index("date", 0)
+            datetime_index = tags.get_date_time_index("datetime", 0)
+            year = timestamp = None
+            for (exists, date) in [date_index, datetime_index]:
                 if exists:
-                    dt = date.to_g_date_time()
-                    if dt is None:
-                        year = date.get_year()
-                        d = Gst.DateTime.new_local_time(year, 1, 1, 0, 0, 0)
-                        dt = d.to_g_date_time()
-                    timestamp = dt.to_unix()
+                    year = date.get_year()
+                    month = date.get_month()
+                    day = date.get_day()
+                    gst_datetime = Gst.DateTime.new_local_time(
+                        year, month, day, 0, 0, 0)
+                    glib_datetime = gst_datetime.to_g_date_time()
+                    timestamp = glib_datetime.to_unix()
             return (year, timestamp)
         except Exception as e:
-            error = "" if tags is None else tags.to_string()
-            Logger.error("TagReader::get_year(): %s, %s", e, error)
+            Logger.error("TagReader::get_year(): %s", e)
         return (None, None)
 
     def get_original_year(self, tags):
@@ -457,6 +452,9 @@ class TagReader:
                     - Windows Media Player is located in m.data[40] and
                       we are searching m.data[10:40] for
                       "Windows Media Player 9 Series"
+                    - MusicBee is located in m.data[19] and
+                      we are searching m.data[10:40] for
+                      "MusicBee"
                 """
                 if m.data[10:40].find(b"Windows Media Player 9 Series") >= 0:
                     location = 40
@@ -473,6 +471,11 @@ class TagReader:
                     Logger.debug(
                         "Rating type: MediaMonkey Location: %s Rating: %s",
                         location, m.data[location])
+                elif m.data[10:40].find(b"MusicBee") >= 0:
+                    location = 19
+                    Logger.debug(
+                        "Rating type: MusicBee Location: %s Rating: %s",
+                        location, m.data[location])
                 else:
                     location = 11
                     Logger.debug(
