@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -35,34 +35,34 @@ def cancellable_sleep(seconds, cancellable):
                 raise Exception("cancelled")
 
 
-def seconds_to_string(duration):
+def ms_to_string(duration):
     """
-        Convert seconds to a pretty string
+        Convert milliseconds to a pretty string
         @param duration as int
     """
-    hours = duration // 3600
+    hours = duration // 3600000
     if hours == 0:
-        minutes = duration // 60
-        seconds = duration % 60
+        minutes = duration // 60000
+        seconds = (duration % 60000) // 1000
         return "%i:%02i" % (minutes, seconds)
     else:
-        seconds = duration % 3600
-        minutes = seconds // 60
-        seconds %= 60
+        seconds = duration % 3600000
+        minutes = seconds // 60000
+        seconds = (duration % 60000) // 1000
         return "%i:%02i:%02i" % (hours, minutes, seconds)
 
 
 def get_human_duration(duration):
     """
         Get human readable duration
-        @param duration in seconds
+        @param duration in milliseconds
         @return str
     """
-    hours = duration // 3600
-    minutes = duration // 60
+    hours = duration // 3600000
+    minutes = duration // 60000
     if hours > 0:
-        seconds = duration % 3600
-        minutes = seconds // 60
+        seconds = duration % 3600000
+        minutes = seconds // 60000
         if minutes > 0:
             return _("%s h  %s m") % (hours, minutes)
         else:
@@ -146,39 +146,36 @@ def on_query_tooltip(label, x, y, keyboard, tooltip):
         return True
 
 
-def set_proxy_from_gnome():
+def init_proxy_from_gnome():
     """
         Set proxy settings from GNOME
+        @return (host, port) as (str, int) or (None, None)
     """
     try:
         proxy = Gio.Settings.new("org.gnome.system.proxy")
         mode = proxy.get_value("mode").get_string()
         if mode == "manual":
-            no_http_proxy = True
-            http = Gio.Settings.new("org.gnome.system.proxy.http")
-            https = Gio.Settings.new("org.gnome.system.proxy.https")
-            h = http.get_value("host").get_string()
-            p = http.get_value("port").get_int32()
-            hs = https.get_value("host").get_string()
-            ps = https.get_value("port").get_int32()
-            if h != "" and p != 0:
-                no_http_proxy = False
-                GLib.setenv("http_proxy", "http://%s:%s" % (h, p), True)
-            if hs != "" and ps != 0:
-                no_http_proxy = False
-                GLib.setenv("https_proxy", "http://%s:%s" % (hs, ps), True)
-            if no_http_proxy:
-                socks = Gio.Settings.new("org.gnome.system.proxy.socks")
-                h = socks.get_value("host").get_string()
-                p = socks.get_value("port").get_int32()
-                # Set socks proxy
-                if h != "" and p != 0:
-                    import socket
-                    import socks
-                    socks.set_default_proxy(socks.SOCKS4, h, p)
-                    socket.socket = socks.socksocket
+            for name in ["org.gnome.system.proxy.http",
+                         "org.gnome.system.proxy.https"]:
+                setting = Gio.Settings.new(name)
+                host = setting.get_value("host").get_string()
+                port = setting.get_value("port").get_int32()
+                if host != "" and port != 0:
+                    return (host, port)
+
+            # Try with a socks proxy
+            # returning host, port not needed as PySocks will override values
+            socks = Gio.Settings.new("org.gnome.system.proxy.socks")
+            host = socks.get_value("host").get_string()
+            port = socks.get_value("port").get_int32()
+            if host != "" and port != 0:
+                import socket
+                import socks
+                socks.set_default_proxy(socks.SOCKS4, host, port)
+                socket.socket = socks.socksocket
     except Exception as e:
-        Logger.error("set_proxy_from_gnome(): %s", e)
+        Logger.warning("set_proxy_from_gnome(): %s", e)
+    return (None, None)
 
 
 def debug(str):
