@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -10,14 +10,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Pango, Gio
+from gi.repository import Gio
 
 from gettext import gettext as _
 from random import shuffle
 
 from lollypop.view_flowbox import FlowBoxView
-from lollypop.define import App, Type, MARGIN, ViewType, OrderBy
-from lollypop.helper_horizontal_scrolling import HorizontalScrollingHelper
+from lollypop.define import App, Type, ViewType, OrderBy
 from lollypop.widgets_artist_rounded import RoundedArtistWidget
 from lollypop.objects_album import Album
 from lollypop.utils import get_icon_name, get_font_height
@@ -44,12 +43,14 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
             (App().scanner, "artist-updated", "_on_artist_updated")
         ]
 
-    def populate(self):
+    def populate(self, artist_ids=[]):
         """
-            Populate view
+            Populate view with artist id
+            Show all artists if empty
+            @param artist_ids as [int]
         """
-        def on_load(items):
-            FlowBoxView.populate(self, items)
+        def on_load(artist_ids):
+            FlowBoxView.populate(self, artist_ids)
 
         def load():
             if App().settings.get_value("show-performers"):
@@ -58,17 +59,10 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
                 ids = App().artists.get()
             return ids
 
-        App().task_helper.run(load, callback=(on_load,))
-
-    def remove_value(self, item_id):
-        """
-            Remove value
-            @param item_id as int
-        """
-        for child in self._box.get_children():
-            if child.data == item_id:
-                child.destroy()
-                break
+        if artist_ids:
+            FlowBoxView.populate(self, artist_ids)
+        else:
+            App().task_helper.run(load, callback=(on_load,))
 
     @property
     def args(self):
@@ -105,16 +99,17 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
         from lollypop.menu_similars import SimilarsMenu
         menu = ArtistMenu(child.data, self._view_type,
                           App().window.is_adaptive)
+        menu_widget = MenuBuilder(menu, False)
+        menu_widget.show()
         section = Gio.Menu()
         menu.append_section(_("Similar artists"), section)
         menu_widget = MenuBuilder(menu, True)
-        scrolled = menu_widget.get_child_by_name("main")
         menu_widget.show()
         menu_ext = SimilarsMenu()
         menu_ext.show()
         menu_ext.populate(child.data)
-        # scrolled -> viewport -> box
-        scrolled.get_child().get_child().add(menu_ext)
+        menu_widget.append_widget(menu_ext)
+        scrolled = menu_widget.get_child_by_name("main")
         scrolled.set_size_request(300, 400)
         return menu_widget
 
@@ -231,102 +226,3 @@ class RoundedArtistsViewWithBanner(RoundedArtistsView):
             App().player.play_album_for_albums(albums[0], albums)
         else:
             App().player.play_album_for_albums(albums[0], albums)
-
-
-class RoundedArtistsRandomView(RoundedArtistsView, HorizontalScrollingHelper):
-    """
-        Show 6 random artists in a FlowBox
-    """
-
-    def __init__(self, view_type):
-        """
-            Init artist view
-            @param view_type as ViewType
-        """
-        RoundedArtistsView.__init__(self, view_type)
-        self.set_row_spacing(5)
-        self._label = Gtk.Label.new()
-        self._label.set_ellipsize(Pango.EllipsizeMode.END)
-        self._label.get_style_context().add_class("dim-label")
-        self.__update_label(App().window.is_adaptive)
-        self._label.set_hexpand(True)
-        self._label.set_property("halign", Gtk.Align.START)
-        self._backward_button = Gtk.Button.new_from_icon_name(
-                                                    "go-previous-symbolic",
-                                                    Gtk.IconSize.BUTTON)
-        self._forward_button = Gtk.Button.new_from_icon_name(
-                                                   "go-next-symbolic",
-                                                   Gtk.IconSize.BUTTON)
-        self._backward_button.get_style_context().add_class("menu-button")
-        self._forward_button.get_style_context().add_class("menu-button")
-        header = Gtk.Grid()
-        header.set_column_spacing(10)
-        header.add(self._label)
-        header.add(self._backward_button)
-        header.add(self._forward_button)
-        header.set_margin_end(MARGIN)
-        header.show_all()
-        HorizontalScrollingHelper.__init__(self)
-        self.add(header)
-        self._label.set_property("halign", Gtk.Align.START)
-        self._box.set_property("halign", Gtk.Align.CENTER)
-        self.add_widget(self._box)
-
-    def populate(self):
-        """
-            Populate view
-        """
-        def on_load(items):
-            self._box.set_min_children_per_line(len(items))
-            FlowBoxView.populate(self, items)
-            if items:
-                self.show()
-
-        def load():
-            ids = App().artists.get_randoms(15)
-            return ids
-
-        self._label.set_text(_("Why not listen to?"))
-        App().task_helper.run(load, callback=(on_load,))
-
-    @property
-    def args(self):
-        return None
-
-#######################
-# PROTECTED           #
-#######################
-    def _on_adaptive_changed(self, window, status):
-        """
-            Update label
-            @param window as Window
-            @param status as bool
-        """
-        RoundedArtistsView._on_adaptive_changed(self, window, status)
-        self.__update_label(status)
-
-    def _on_populated(self, widget):
-        """
-            Update button state
-            @param widget as Gtk.Widget
-        """
-        RoundedArtistsView._on_populated(self, widget)
-        if self.is_populated:
-            self._update_buttons()
-
-    def _on_artist_updated(self, scanner, artist_id, add):
-        pass
-
-#######################
-# PRIVATE             #
-#######################
-    def __update_label(self, is_adaptive):
-        """
-            Update label style based on current adaptive state
-            @param is_adaptive as bool
-        """
-        style_context = self._label.get_style_context()
-        if is_adaptive:
-            style_context.remove_class("text-x-large")
-        else:
-            style_context.add_class("text-x-large")
