@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -17,7 +17,7 @@ from locale import strcoll
 from lollypop.view_lazyloading import LazyLoadingView
 from lollypop.helper_filtering import FilteringHelper
 from lollypop.helper_gestures import GesturesHelper
-from lollypop.define import ViewType, MARGIN
+from lollypop.define import ViewType, App
 from lollypop.utils import get_font_height, popup_widget
 
 
@@ -42,13 +42,12 @@ class FlowBoxView(FilteringHelper, LazyLoadingView, GesturesHelper):
         self._box.set_homogeneous(True)
         self._box.set_vexpand(True)
         self._box.set_max_children_per_line(1000)
-        self._box.set_row_spacing(MARGIN)
-        self._box.set_column_spacing(MARGIN)
         self._box.set_property("valign", Gtk.Align.START)
         self._box.connect("child-activated", self._on_child_activated)
         self._box.show()
-        self.__event_controller = Gtk.EventControllerMotion.new(self._box)
-        self.__event_controller.connect("motion", self.__on_box_motion)
+        if App().animations:
+            self.__event_controller = Gtk.EventControllerMotion.new(self._box)
+            self.__event_controller.connect("motion", self.__on_box_motion)
         GesturesHelper.__init__(self, self._box)
 
     def populate(self, items):
@@ -77,6 +76,13 @@ class FlowBoxView(FilteringHelper, LazyLoadingView, GesturesHelper):
                 child.destroy()
                 break
 
+    def clear(self):
+        """
+            Clear flowbox
+        """
+        for child in self._box.get_children():
+            child.destroy()
+
     def activate_child(self):
         """
             Activated typeahead row
@@ -208,8 +214,10 @@ class FlowBoxView(FilteringHelper, LazyLoadingView, GesturesHelper):
         """
             Unselect selected child
         """
-        if self.__hovered_child is not None:
-            self.__hovered_child.set_opacity(1)
+        if self.__hovered_child is not None and\
+                self.__hovered_child.artwork is not None:
+            self.__hovered_child.artwork.unset_state_flags(
+                Gtk.StateFlags.VISITED)
             self.__hovered_child = None
 
     def __on_box_motion(self, event_controller, x, y):
@@ -222,7 +230,9 @@ class FlowBoxView(FilteringHelper, LazyLoadingView, GesturesHelper):
         child = self._box.get_child_at_pos(x, y)
         if child == self.__hovered_child:
             return
-        elif child is not None:
-            child.set_opacity(0.9)
+        elif child is not None and child.artwork is not None:
+            child.artwork.set_state_flags(Gtk.StateFlags.VISITED, False)
             self.__unselect_selected()
             self.__hovered_child = child
+        else:
+            self.__unselect_selected()
