@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -37,14 +37,25 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
             @param scrolled as bool
         """
         Gtk.Stack.__init__(self)
+        self.__built = False
         self.__boxes = {}
         self.__menu_queue = []
         self.__submenu_queue = []
+        self.__widgets_queue = []
         self.__add_menu(menu, "main", False, scrolled)
         return [
             (App().window, "adaptive-changed", "_on_adaptive_changed")
         ]
 
+    def append_widget(self, widget):
+        """
+            Append widget to menu
+            @param widget as Gtk.Widget
+        """
+        self.__widgets_queue.append(widget)
+        if self.__built:
+            self.__add_widgets()
+
 #######################
 # PROTECTED           #
 #######################
@@ -60,6 +71,18 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
 #######################
 # PRIVATE             #
 #######################
+    def __add_widgets(self):
+        """
+            Add pending widget to menu
+        """
+        main = self.get_child_by_name("main")
+        if isinstance(main, Gtk.ScrolledWindow):
+            # scrolled -> viewport -> box
+            main = main.get_child().get_child()
+        while self.__widgets_queue:
+            widget = self.__widgets_queue.pop(0)
+            main.add(widget)
+
     def __add_menu(self, menu, menu_name, submenu, scrolled):
         """
             Build menu
@@ -131,6 +154,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 else:
                     icon_name = header[2]
                     self.__add_header(header_label, icon_name, menu_name)
+                GLib.idle_add(self.__add_menu_items, menu, menu_name, indexes)
             elif action is None:
                 link = menu.get_item_link(i, "section")
                 submenu = menu.get_item_link(i, "submenu")
@@ -154,6 +178,9 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         elif self.__submenu_queue:
             (menu, menu_name, indexes) = self.__submenu_queue.pop(-1)
             GLib.idle_add(self.__add_menu_items, menu, menu_name, indexes)
+        else:
+            self.__built = True
+            self.__add_widgets()
 
     def __add_item(self, text, action, target, tooltip, close, menu_name):
         """
